######################################################################################################################
#
# spec file for package freeswitch
#
# includes module(s): freeswitch-devel freeswitch-codec-passthru-amr freeswitch-codec-passthru-amrwb freeswitch-codec-passthru-g729 
#                     freeswitch-codec-passthru-g7231 freeswitch-lua freeswitch-mariadb freeswitch-pgsql freeswitch-perl freeswitch-v8 freeswitch-signalwire
#                     freeswitch-lan-de freeswitch-lang-en freeswitch-lang-fr freeswitch-lang-hu freeswitch-lang-ru
#		      and others
#
# Initial Version Copyright (C) 2007 Peter Nixon and Michal Bielicki, All Rights Reserved.
#
# This file is part of:
# FreeSWITCH Modular Media Switching Software Library / Soft-Switch Application
# Copyright (C) 2005-2015, Anthony Minessale II <anthm@freeswitch.org>
#
# This file and all modifications and additions to the pristine package are under the same license as the package itself.
#
# Contributor(s): Mike Jerris
#                 Brian West
#                 Anthony Minessale II <anthm@freeswitch.org>
#                 Raul Fragoso
#                 Rupa Shomaker
#                 Marc Olivier Chouinard
#                 Raymond Chandler
#                 Ken Rice <krice@freeswitch.org>
#                 Chris Rienzo <crienzo@grasshopper.com>
#
# Maintainer(s): SignalWire, Inc <support@signalwire.com>
#
######################################################################################################################

%bcond core_vpx 0
%bcond pocketsphinx 0


# Module build settings
%define build_py26_esl 0
%define build_timerfd 0
%define build_mod_esl 1
%define build_mod_perl 0
#mod_v8 needs static lib version of v8 or something
%define build_mod_v8 0
%define build_signalwire 0
%define build_mongo 0
%define build_pocketsphinx 0

%define build_hard_modules 0
%define build_modules 1

%{?with_modules:%define build_modules 1}
%{?with_hard_modules:%define build_hard_modules 1}

%{?with_py26_esl:%define build_py26_esl 1 }
%{?with_timerfd:%define build_timerfd 1 }
%{?with_mod_esl:%define build_mod_esl 1 }
%{?with_mod_v8:%define build_mod_v8 1 }

%define nonparsedversion 1.10-dev
%define version %(echo '%{nonparsedversion}' | sed 's/-//g')
%define release 3

######################################################################################################################
# Layout of packages FHS (Redhat/SUSE), FS (Standard FreeSWITCH layout using /usr/local), OPT (/opt based layout)
%define packagelayout	FHS

%define	PREFIX		%{_prefix}
%define EXECPREFIX	%{_exec_prefix}
%define BINDIR		%{_bindir}
%define SBINDIR		%{_sbindir}
%define LIBEXECDIR	%{_libexecdir}/%name
%define SYSCONFDIR	%{_sysconfdir}/%name
%define SHARESTATEDIR	%{_sharedstatedir}/%name
%define LOCALSTATEDIR	%{_localstatedir}/lib/%name
%define LIBDIR		%{_libdir}
%define INCLUDEDIR	%{_includedir}
%define _datarootdir	%{_prefix}/share
%define DATAROOTDIR	%{_datarootdir}
%define DATADIR		%{_datadir}
%define INFODIR		%{_infodir}
%define LOCALEDIR	%{_datarootdir}/locale
%define MANDIR		%{_mandir}
%define DOCDIR		%{_defaultdocdir}/%name
%define HTMLDIR		%{_defaultdocdir}/%name/html
%define DVIDIR		%{_defaultdocdir}/%name/dvi
%define PDFDIR		%{_defaultdocdir}/%name/pdf
%define PSDIR		%{_defaultdocdir}/%name/ps
%define LOGFILEDIR	/var/log/%name
%define MODINSTDIR	%{_libdir}/%name/mod
%define RUNDIR		%{_localstatedir}/run/%name
%define DBDIR		%{LOCALSTATEDIR}/db
%define HTDOCSDIR	%{_datarootdir}/%name/htdocs
%define SOUNDSDIR	%{_datarootdir}/%name/sounds
%define GRAMMARDIR	%{_datarootdir}/%name/grammar
%define SCRIPTDIR	%{_datarootdir}/%name/scripts
%define RECORDINGSDIR	%{LOCALSTATEDIR}/recordings
%define PKGCONFIGDIR	%{_datarootdir}/%name/pkgconfig
%define HOMEDIR		%{LOCALSTATEDIR}
%define perl_archlib    %{_libdir}/perl5/

Name:         	freeswitch
Summary:      	FreeSWITCH open source telephony platform
License:      	MPL1.1
Version:	%{version}
Release:	%{release}%{?dist}
URL:          	http://www.freeswitch.org/
Packager:     	Ken Rice
Vendor:       	http://www.freeswitch.org/

######################################################################################################################
#
#					Source files and where to get them
#
######################################################################################################################
Source0:        %{name}-%{version}.tar.gz
Patch:         freeswitch.patch
######################################################################################################################
#
#				Build Dependencies
#
######################################################################################################################

Provides: user(freeswitch)
Provides: group(freeswitch)

%if 0%{?suse_version} > 100
BuildRequires: lzo-devel
%endif
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: curl-devel >= 7.19
BuildRequires: chrpath
BuildRequires: gcc-c++
BuildRequires: libtool >= 1.5.17
BuildRequires: openssl-devel >= 1.0.1e
BuildRequires: sofia-sip-devel >= 1.13.17
BuildRequires: spandsp3-devel >= 3.0
BuildRequires: pcre-devel
BuildRequires: speex-devel
BuildRequires: speexdsp-devel
BuildRequires: sqlite-devel >= 3.6.20
BuildRequires: libtiff-devel
BuildRequires: libedit-devel
BuildRequires: yasm
BuildRequires: pkgconfig
BuildRequires: unixODBC-devel
BuildRequires: libjpeg-devel
BuildRequires: which
BuildRequires: zlib-devel
BuildRequires: libxml2-devel
BuildRequires: libsndfile-devel
BuildRequires: libuuid-devel
BuildRequires: gumbo-parser-devel
Requires: %{name}-libs = %{version}-%{release}
Requires: %{name}-base-modules = %{version}-%{release}

Recommends: %{name}-config-vanilla

######################################################################################################################
#
#					Where the packages are going to be built
#
######################################################################################################################
BuildRoot:    %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

%description
FreeSWITCH is an open source telephony platform designed to facilitate the creation of voice 
and chat driven products scaling from a soft-phone up to a soft-switch.  It can be used as a 
simple switching engine, a media gateway or a media server to host IVR applications using 
simple scripts or XML to control the callflow. 

We support various communication technologies such as SIP, H.323 and GoogleTalk making 
it easy to interface with other open source PBX systems such as sipX, OpenPBX, Bayonne, YATE or Asterisk.

We also support both wide and narrow band codecs making it an ideal solution to bridge legacy 
devices to the future. The voice channels and the conference bridge module all can operate 
at 8, 16 or 32 kilohertz and can bridge channels of different rates.

FreeSWITCH runs on several operating systems including Windows, Max OS X, Linux, BSD and Solaris 
on both 32 and 64 bit platforms.

Our developers are heavily involved in open source and have donated code and other resources to 
other telephony projects including sipXecs, OpenSER, Asterisk, CodeWeaver and OpenPBX.


######################################################################################################################
#
#		    Sub Package definitions. Description and Runtime Requirements go here
#		What goes into which package is in the files section after the whole build enchilada
#
######################################################################################################################


%package devel
Summary:        Development package for FreeSWITCH open source telephony platform
Requires:       %{name}-libs = %{version}-%{release}

%description devel
FreeSWITCH development files

%package libs
Summary: Freeswitch library files
Requires: curl >= 7.19
Requires: pcre
Requires: speex
Requires: speexdsp
Requires: sqlite >= 3.6.20
Requires: libtiff
Requires: libedit
Requires: openssl >= 1.0.1e
Requires: unixODBC
Requires: libjpeg
Requires: zlib
Requires: libxml2
Requires: libsndfile

%description libs
Freeswitch base library files

%package cli
Summary: FreeSWITCH control cli

%description cli
Provide a CLI to control FreeSWITCH instances
Requires: libedit
Requires: ncurses-libs
Requires: zlib
Requires: openssl-libs

%package utils
Summary: Extra utilities for FreeSWITCH
Requires: %{name}-libs = %{version}-%{release}

%description utils
Utilities using freeswitch library

%package base-modules
Summary: Base modules for FreeSWITCH
Requires: %{name}-libs = %{version}-%{release}


Provides:      %{name}-mod-cdr-csv
Provides:      %{name}-mod-console
Provides:      %{name}-mod-commands
Provides:      %{name}-mod-dialplan-directory
Provides:      %{name}-mod-dialplan-xml
Provides:      %{name}-mod-dptools
Provides:      %{name}-mod-event-socket
Provides:      %{name}-mod-logfile
Provides:      %{name}-mod-loopback
Provides:      %{name}-mod-native-file
Provides:      %{name}-mod-sndfile
Provides:      %{name}-mod-sofia
Provides:      %{name}-mod-spandsp
Provides:      %{name}-mod-syslog
Provides:      %{name}-mod-tone-stream
%description base-modules
Base modules for FreeSWITCH
%package extra-modules
Summary: Extra modules for FreeSWITCH that don't have a separate package yet
Requires: %{name}-libs = %{version}-%{release}
BuildRequires: librabbitmq-devel
BuildRequires: alsa-lib-devel
BuildRequires: opencv-devel
BuildRequires: ptlib-devel
BuildRequires: hiredis-devel
BuildRequires: ImageMagick-devel
BuildRequires: openldap-devel
BuildRequires: noopenh264-devel
#BuildRequires: osp-devel
BuildRequires: python3-devel
BuildRequires: vlc-devel
#mod_opal
BuildRequires: opal-devel
#BuildRequires: java-devel
%description extra-modules
Base modules for FreeSWITCH

%if %{build_modules}
######################################################################################################################
#				FreeSWITCH Application Modules
######################################################################################################################
%package application-avmd
Summary:	FreeSWITCH voicemail detector
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-avmd

%description application-avmd
Provide an voicemail beep detector for FreeSWITCH

%package application-blacklist
Summary:	FreeSWITCH blacklist module
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-blacklist

%description application-blacklist
Provide black/white listing of various fields used for routing calls in 
FreeSWITCH

%package application-callcenter
Summary:	FreeSWITCH mod_callcenter Call Queuing Application
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-callcenter

%description application-callcenter
Provide Automated Call Distribution capabilities for FreeSWITCH

%package application-cidlookup
Summary:	FreeSWITCH mod_cidlookup 
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-cidlookup

%description application-cidlookup
Provide FreeSWITCH access to third party CallerID Name Databases via HTTP

%package application-conference
Summary:	FreeSWITCH mod_conference
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-conference

%description application-conference
Provide FreeSWITCH Conference Bridge Services. 

%package application-curl
Summary:	FreeSWITCH mod_curl
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-curl

%description application-curl
Provide FreeSWITCH dialplan access to CURL

%package application-db
Summary:	FreeSWITCH mod_db
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-db

%description application-db
mod_db implements an API and dialplan interface to a database backend for 
FreeSWITCH.  The database can either be in sqlite or ODBC.  It also provides 
support for group dialing and provides database backed limit interface. 

%package application-directory
Summary:	FreeSWITCH mod_directory
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-directory

%description application-directory
Provides FreeSWITCH mod_directory, a dial by name directory application.

%package application-distributor
Summary:	FreeSWITCH mod_distributor
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-distributor

%description application-distributor
Provides FreeSWITCH mod_distributor, a simple round-robin style distribution
to call gateways.

%package application-easyroute
Summary:	FreeSWITCH mod_easyroute
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-easyroute

%description application-easyroute
Provides FreeSWITCH mod_easyroute, a simple, easy to use DB Backed DID routing 
Engine. Uses ODBC to connect to the DB of your choice.

%package application-enum
Summary:	FreeSWITCH mod_enum
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
BuildRequires:  ldns-devel
Provides:      %{name}-mod-enum

%description application-enum
Provides FreeSWITCH mod_enum, a ENUM dialplan, with API and Dialplan extensions 
supporting ENUM lookups.

%package application-esf
Summary:	FreeSWITCH mod_esf
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-esf

%description application-esf
Provides FreeSWITCH mod_esf, Extra Sip Functionality such as Multicast Support

%if %{build_mod_esl}
%package application-esl
Summary:	FreeSWITCH mod_esl
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-esl

%description application-esl
Provides FreeSWITCH mod_esl, add api commands for remote ESL commands
%endif

%package application-expr
Summary:	FreeSWITCH mod_expr
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-expr

%description application-expr
Provides FreeSWITCH mod_expr, implements Brian Allen Vanderburg's ExprEval 
expression evaluation library for FreeSWITCH.

%package application-fifo
Summary:	FreeSWITCH mod_fifo
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-fifo

%description application-fifo
Provides FreeSWITCH mod_fifo, a parking-like app which allows you to make 
custom call queues

%package application-fsk
Summary:	FreeSWITCH mod_fsk
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-fsk

%description application-fsk
Provides FreeSWITCH mod_fsk, a module to send and receive information via 
Frequency-shift keying

%package application-fsv
Summary:	FreeSWITCH mod_fsv
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-fsv

%description application-fsv
Provides FreeSWITCH mod_fsk, implements functions to record and play back video

%package application-hash
Summary:	FreeSWITCH mod_hash
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-hash

%description application-hash
Provides FreeSWITCH mod_hash, implements an API and application interface for 
manipulating a hash table. It also provides a limit backend. 

%package application-httapi
Summary:	FreeSWITCH mod_httapi
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-httpapi

%description application-httapi
Provides FreeSWITCH mod_httapi, provides an HTTP based Telephony API using a 
standard FreeSWITCH application interface as well as a cached http file format 
interface

%package application-http-cache
Summary:	FreeSWITCH mod_http_cache
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-http-cache

%description application-http-cache
Provides FreeSWITCH mod_http_cache, allows one to make a HTTP GET request to 
cache a document. The primary use case is to download and cache audio files 
from a web server. 

%package application-lcr
Summary:	FreeSWITCH mod_lcr
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-lcr

%description application-lcr
Provides FreeSWITCH mod_lcr, provide basic Least Cost Routing Services

%package application-limit
Summary:	FreeSWITCH mod_limit
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-limit

%description application-limit
Provides FreeSWITCH mod_limit, provide application to limit both concurrent and call per time period

%package application-memcache
Summary:	FreeSWITCH mod_memcache
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
BuildRequires:  libmemcached-devel
Provides:      %{name}-mod-memcache

%description application-memcache
Provides FreeSWITCH mod_memcache, implements an API interface to memcached which
is a "high-performance, distributed memory object caching system, generic in 
nature, but intended for use in speeding up dynamic web applications by 
alleviating database load." 

%if %{build_mongo}
%package application-mongo
Summary:	FreeSWITCH mod_mongo
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}
BuildRequires:  mongo-c-driver-devel
BuildRequires:  libmongo-client-devel
Provides:      %{name}-mod-mongo

%description application-mongo
Provides FreeSWITCH mod_mongo, which implements an API interface to mongodb.
%endif

%package application-nibblebill
Summary:	FreeSWITCH mod_nibblebill
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-nibblebill

%description application-nibblebill
Provides FreeSWITCH mod_nibblebill, provides a credit/debit module for 
FreeSWITCH to allow real-time debiting of credit or cash from a database 
while calls are in progress.

%package application-redis
Summary:	FreeSWITCH mod_redis
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-redis

%description application-redis
Provides FreeSWITCH mod_redis, access to the redis key value pair db system from
FreeSWITCH

%if %{build_signalwire}
%package application-signalwire
Summary:	FreeSWITCH mod_signalwire
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
BuildRequires:  libks2 signalwire-client-c2
Provides:      %{name}-mod-signalwire

%description application-signalwire
Provides FreeSWITCH mod_signalwire
%endif

%package application-sms
Summary:	FreeSWITCH mod_sms
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-sms

%description application-sms
Provides FreeSWITCH mod_sms, provide a way to route messages in freeswitch, 
potentially allowing one to build a powerful chatting system like in XMPP using 
using SIP SIMPLE on SIP clients

%package application-snapshot
Summary:	FreeSWITCH mod_snapshot
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-snapshot

%description application-snapshot
Provides FreeSWITCH mod_snapshot, allows recording a sliding window of audio 
and taking snapshots to disk. 

%package application-spy
Summary:	FreeSWITCH mod_spy
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-spy

%description application-spy
Provides FreeSWITCH mod_spy, implements userspy application which provides 
persistent eavesdrop on all channels bridged to a certain user

%package application-translate
Summary:	FreeSWITCH mod_translate
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-translate

%description application-translate
Provide an number translation to FreeSWITCH API calls

%package application-valet_parking
Summary:	FreeSWITCH mod_valet_parking
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-valet-parking

%description application-valet_parking
Provides FreeSWITCH mod_valet_parking. Provides 'Call Parking' in the switch
as opposed to on the phone and allows for a number of options to handle call
retrieval

%package application-video_filter
Summary:	FreeSWITCH video filter bugs
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-video-filter

%description application-video_filter
Provide a chromakey video filter media bug

%package application-voicemail
Summary:	FreeSWITCH mod_voicemail
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-voicemail

%description application-voicemail
Provides FreeSWITCH mod_voicemail. Implements Voicemail Application 

%package application-voicemail-ivr
Summary:	FreeSWITCH mod_voicemail_ivr
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-voicemail-ivr

%description application-voicemail-ivr
Provides FreeSWITCH mod_voicemail_ivr. Provides a custimizable audio navigation 
system for backend voicemail systems

%endif

######################################################################################################################
#				FreeSWITCH ASR TTS Modules
######################################################################################################################
%if %{build_modules}

%package asrtts-flite
Summary:	FreeSWITCH mod_flite
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Requires:       flite >= 2.0.0
BuildRequires:  flite-devel >= 2.0.0
Provides:      %{name}-mod-flite

%description asrtts-flite
Provides FreeSWITCH mod_flite, a interface to the flite text to speech engine

%if %{build_pocketsphinx}
%package asrtts-pocketsphinx
Summary:	FreeSWITCH mod_pocketsphinx
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
BuildRequires:  bison
Provides:      %{name}-mod-pocketsphinx

%description asrtts-pocketsphinx
Provides FreeSWITCH mod_pocketsphinx, a interface to the OpenSource 
Pocketsphinx speech recognition engine
%endif

%package asrtts-tts-commandline
Summary:	FreeSWITCH mod_tts_commandline
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-tts-commandline

%description asrtts-tts-commandline
Provides FreeSWITCH mod_tts_commandline, Run a command line and play the 
output file.

%endif
######################################################################################################################
#				FreeSWITCH Codec Modules
######################################################################################################################
%if %{build_modules}

%package codec-libav
Summary:        libav Codec support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
BuildRequires:  libavformat-free-devel
BuildRequires:  libswscale-free-devel
Provides:      %{name}-mod-av

%description codec-libav
libav codec support for FreeSWITCH open source telephony platform

%package codec-passthru-amr
Summary:        Pass-through AMR Codec support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Conflicts:	codec-amr
Provides:      %{name}-mod-amr

%description codec-passthru-amr
Pass-through AMR Codec support for FreeSWITCH open source telephony platform

%package codec-passthru-amrwb
Summary:        Pass-through AMR WideBand Codec support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Conflicts:      codec-amrwb
Provides:      %{name}-mod-amrwb

%description codec-passthru-amrwb
Pass-through AMR WideBand Codec support for FreeSWITCH open source telephony platform

%package codec-bv
Summary:        BroadVoice16 and BroadVoice32 WideBand Codec support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
BuildRequires:  libbroadvoice-devel

%description codec-bv
BroadVoice16 and BroadVoice32 WideBand Codec support for FreeSWITCH open source telephony platform

%package codec-codec2
Summary:        Codec2 Narrow Band Codec support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
BuildRequires:  codec2-devel
Provides:      %{name}-mod-codec2

%description codec-codec2
CODEC2 narrow band codec support for FreeSWITCH open source telephony platform.
CODEC2 was created by the developers of Speex.

%package codec-passthru-g723_1
Summary:        Pass-through g723.1 Codec support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Conflicts:	codec-g723_1

%description codec-passthru-g723_1
Pass-through g723.1 Codec support for FreeSWITCH open source telephony platform

%package codec-passthru-g729
Summary:        Pass-through g729 Codec support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Conflicts:	codec-com-g729
Provides:      %{name}-mod-g729

%description codec-passthru-g729
Pass-through g729 Codec support for FreeSWITCH open source telephony platform

%package codec-ilbc
Summary:        iLCB Codec support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Requires:       ilbc2
BuildRequires:  ilbc2-devel 
Provides:      %{name}-mod-ilbc

%description codec-ilbc
iLBC Codec support for FreeSWITCH open source telephony platform

%package codec-vpx
Summary:        vp8 Codec support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-vpx

%description codec-vpx
VP8 Codec support for FreeSWITCH open source telephony platform

%package codec-opus
Summary:        Opus Codec support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Requires:       opus >= 1.1
BuildRequires:  opus-devel >= 1.1
Provides:      %{name}-mod-opus

%description codec-opus
OPUS Codec support for FreeSWITCH open source telephony platform

%package codec-silk
Summary:        Silk Codec support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
BuildRequires:  libsilk-devel
Provides:      %{name}-mod-silk

%description codec-silk
Silk Codec (from Skype) support for FreeSWITCH open source telephony platform

%package codec-siren
Summary:        Siren Codec support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
BuildRequires:  g722_1-devel
Provides:      %{name}-mod-siren

%description codec-siren
Siren Codec support for FreeSWITCH open source telephony platform. Using 
mod_siren in a commercial product will require you to acquire a patent license
directly from Polycom(R) for your company. 
see http://www.polycom.com/usa/en/company/about_us/technology/siren_g7221/siren_g7221.html 
and http://www.polycom.com/usa/en/company/about_us/technology/siren14_g7221c/siren14_g7221c.html 
At the time of this packaging, Polycom does not charge for licensing.

%endif
######################################################################################################################
#				FreeSWITCH Database Modules
######################################################################################################################
%if %{build_modules}

%package database-mariadb
Summary:	MariaDB native support for FreeSWITCH
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}
Requires:	mariadb-connector-c
BuildRequires:	mariadb-connector-c-devel
Provides:      %{name}-mod-mariadb

%description database-mariadb
MariaDB native support for FreeSWITCH.

%package database-pgsql
Summary:	PostgreSQL native support for FreeSWITCH
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}
Requires:	postgresql-libs
BuildRequires:	postgresql-devel
Provides:      %{name}-mod-pgsql

%description database-pgsql
PostgreSQL native support for FreeSWITCH.

%endif
######################################################################################################################
#				FreeSWITCH Directory Modules
######################################################################################################################

%package directory-ldap
Summary:        LDAP Directory support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
BuildRequires:  openldap-devel
Requires: openldap
%description directory-ldap
LDAP Directory support for FreeSWITCH open source telephony platform.

######################################################################################################################
#				FreeSWITCH Endpoint Modules
######################################################################################################################

#%package endpoint-h323
#Summary:        H.323 endpoint support for FreeSWITCH open source telephony platform
#Group:          System/Libraries
#Requires:       %{name}-libs = %{version}-%{release}
#
#%description endpoint-h323
#H.323 endpoint support for FreeSWITCH open source telephony platform

%if %{build_modules}

%package endpoint-rtmp
Summary:        RTPM Endpoint support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}

%description endpoint-rtmp
RTMP Endpoint support for FreeSWITCH open source telephony platform. Allows FreeSWITCH
to be used from a RTMP client. See http://wiki.freeswitch.org/wiki/Mod_rtmp#Flex_Client
for the OpenSouce FreeSWITCH backed Client.

%package endpoint-skinny
Summary:        Skinny/SCCP endpoint support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}

%description endpoint-skinny
SCCP/Skinny support for FreeSWITCH open source telephony platform.

%if %{build_signalwire}
%package endpoint-verto
Summary:        Verto endpoint support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}

%description endpoint-verto
Verto protocol support for FreeSWITCH open source telephony platform.
%endif
%package endpoint-rtc
Summary:        Verto endpoint support for FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}

%description endpoint-rtc
Verto protocol support for FreeSWITCH open source telephony platform.

%endif
######################################################################################################################
#				FreeSWITCH Event Handler Modules
######################################################################################################################
%if %{build_modules}

%package event-cdr-mongodb
Summary:	MongoDB CDR Logger for the FreeSWITCH open source telephony platform
Group:		System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
BuildRequires:  mongo-c-driver-devel

%description event-cdr-mongodb
MongoDB CDR Logger for FreeSWITCH

%package event-cdr-pg-csv
Summary:	PostgreSQL CDR Logger for the FreeSWITCH open source telephony platform
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}
Requires:	postgresql-libs
BuildRequires:	postgresql-devel

%description event-cdr-pg-csv
PostgreSQL CDR Logger for FreeSWITCH.

%package event-cdr-sqlite
Summary:	SQLite CDR Logger for the FreeSWITCH open source telephony platform
Group:		System/Libraries
Requires:	 %{name}-libs = %{version}-%{release}

%description event-cdr-sqlite
SQLite CDR Logger for FreeSWITCH.

%package event-erlang-event
Summary:	Erlang Event Module for the FreeSWITCH open source telephony platform
Group:		System/Libraries
Requires:	 %{name}-libs = %{version}-%{release}
Requires:	erlang
BuildRequires:	erlang

%description event-erlang-event
Erlang Event Module for FreeSWITCH.

%package event-format-cdr
Summary:        JSON and XML Logger for the FreeSWITCH open source telephony platform
Group:          System/Libraries
Requires:        %{name}-libs = %{version}-%{release}

%description event-format-cdr
JSON and XML Logger for the FreeSWITCH open source telephony platform

%package event-multicast
Summary:	Multicast Event System for the FreeSWITCH open source telephony platform
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}

%description event-multicast
Multicast Event System for FreeSWITCH.

%package event-json-cdr
Summary:	JSON CDR Logger for the FreeSWITCH open source telephony platform
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}

%description event-json-cdr
JSON CDR Logger for FreeSWITCH.

%package event-snmp
Summary:	SNMP stats reporter for the FreeSWITCH open source telephony platform
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}
Requires:	net-snmp
BuildRequires:	net-snmp-devel

%description event-snmp
SNMP stats reporter for the FreeSWITCH open source telephony platform

%endif
######################################################################################################################
#				FreeSWITCH Logger Modules
######################################################################################################################
%if %{build_modules}

%package logger-graylog2
Summary:	GELF logger for Graylog2 and Logstash
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}

%description logger-graylog2
GELF logger for Graylog2 and Logstash
%endif
######################################################################################################################
#				FreeSWITCH Media Format Modules
######################################################################################################################
%if %{build_modules}

%package format-local-stream
Summary:	Local File Streamer for the FreeSWITCH open source telephony platform
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}

%description format-local-stream
Local File Streamer for FreeSWITCH. It streams files from a directory and 
multiple channels connected to the same stream will hear the same (looped) 
file playback .. similar to a shoutcast stream. Useful for Music-on-hold type 
scenarios. 

%package format-native-file
Summary:	Native Media File support for the FreeSWITCH open source telephony platform
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}

%description format-native-file
The native file module is designed to make it easy to play sound files where no
transcoding is necessary. The default FreeSWITCH sound files are in wav format.
Generally, these require transcoding when being played to callers. However, if
a native format sound file is available then FreeSWITCH can use it. 

%package format-shell-stream
Summary:	Implements Media Steaming from arbitrary shell commands for the FreeSWITCH open source telephony platform
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}

%description format-shell-stream
Mod shell stream is a FreeSWITCH module to allow you to stream audio from an 
arbitrary shell command. You could use it to read audio from a database, from 
a soundcard, etc. 

%package format-mod-shout
Summary:	Implements Media Steaming from arbitrary shell commands for the FreeSWITCH open source telephony platform
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}
Requires:	libshout >= 2.2.2
Requires:	libmpg123 >= 1.20.1
Requires:	lame
BuildRequires:	libshout-devel >= 2.2.2
BuildRequires:	libmpg123-devel >= 1.20.1
BuildRequires:	lame-devel

%description format-mod-shout
Mod Shout is a FreeSWITCH module to allow you to stream audio from MP3s or a i
shoutcast stream.

%package format-opusfile
Summary:	Plays Opus encoded files
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}
Requires:	opusfile >= 0.5
BuildRequires:	opusfile-devel >= 0.5

%description format-opusfile
Mod Opusfile is a FreeSWITCH module to allow you to play Opus encoded files

%package format-tone-stream
Summary:	Implements TGML Tone Generation for the FreeSWITCH open source telephony platform
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}

%description format-tone-stream
Implements TGML Tone Generation for the FreeSWITCH open source telephony platform
%endif

######################################################################################################################
#				FreeSWITCH Programming Language Modules
######################################################################################################################
%if %{build_modules}

%package lua
Summary:	Lua support for the FreeSWITCH open source telephony platform
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}
BuildRequires:  lua-devel

%description	lua

%if %{build_mod_perl}
%package	perl
Summary:	Perl support for the FreeSWITCH open source telephony platform
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}
Requires:	perl
BuildRequires:	perl-devel
BuildRequires:	perl-ExtUtils-Embed

%description	perl
%endif

%if %{build_mod_v8}
%package v8
Summary:	JavaScript support for the FreeSWITCH open source telephony platform, using Google V8 JavaScript engine
Group:		System/Libraries
Requires:	%{name}-libs = %{version}-%{release}
BuildRequires: v8-devel

%description v8
%endif
%endif
######################################################################################################################
#				FreeSWITCH Say Modules
######################################################################################################################

%package lang-en
Summary:	Provides english language dependent modules and speech config for the FreeSWITCH Open Source telephone platform.
Group:          System/Libraries
Requires:        %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-say-en

%description lang-en
English language phrases module and directory structure for say module and voicemail

%package lang-ru
Summary:        Provides russian language dependent modules and speech config for the FreeSWITCH Open Source telephone platform.
Group:          System/Libraries
Requires:        %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-say-ru

%description lang-ru
Russian language phrases module and directory structure for say module and voicemail

%package lang-fr
Summary:        Provides french language dependend modules and speech config for the FreeSWITCH Open Source telephone platform.
Group:          System/Libraries
Requires:        %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-say-fr

%description lang-fr
French language phrases module and directory structure for say module and voicemail

%package lang-de
Summary:        Provides german language dependend modules and speech config for the FreeSWITCH Open Source telephone platform.
Group:          System/Libraries
Requires:        %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-say-de

%description lang-de
German language phrases module and directory structure for say module and voicemail

%package lang-he
Summary:        Provides hebrew language dependend modules and speech config for the FreeSWITCH Open Source telephone platform.
Group:          System/Libraries
Requires:        %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-say-he

%description lang-he
Hebrew language phrases module and directory structure for say module and voicemail

%package lang-es
Summary:        Provides Spanish language dependend modules and speech config for the FreeSWITCH Open Source telephone platform.
Group:          System/Libraries
Requires:        %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-say-es

%description lang-es
Spanish language phrases module and directory structure for say module and voicemail

%package lang-pt
Summary:        Provides Portuguese language dependend modules and speech config for the FreeSWITCH Open Source telephone platform.
Group:          System/Libraries
Requires:        %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-say-pt

%description lang-pt
Portuguese language phrases module and directory structure for say module and voicemail

%package lang-sv
Summary:        Provides Swedish language dependend modules and speech config for the FreeSWITCH Open Source telephone platform.
Group:          System/Libraries
Requires:        %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-say-sv

%description lang-sv
Swedish language phrases module and directory structure for say module and voicemail

######################################################################################################################
#				FreeSWITCH Timer Modules
######################################################################################################################
%if %{build_modules}

%package timer-posix
Summary:        Provides posix timer for the FreeSWITCH Open Source telephone platform.
Group:          System/Libraries
Requires:        %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-timer-posix

%description timer-posix
Provides posix timer for the FreeSWITCH Open Source telephone platform.

%if %{build_timerfd}
%package timer-timerfd
Summary:        Provides Linux Timerfs based timer for the FreeSWITCH Open Source telephone platform.
Group:          System/Libraries
Requires:        %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-timerfd

%description timer-timerfd
Provides Linux Timerfs based timer for the FreeSWITCH Open Source telephone 
platform.
%endif
%endif
######################################################################################################################
#				FreeSWITCH XML INT Modules
######################################################################################################################
%if %{build_modules}

%package xml-cdr
Summary:        Provides XML CDR interface for the FreeSWITCH Open Source telephone platform.
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-xml-cdr

%description xml-cdr
Provides XML CDR interface for the FreeSWITCH Open Source telephone platform.

%package xml-curl
Summary:        Provides XML Curl interface for the FreeSWITCH Open Source telephone platform.
Group:          System/Libraries
Requires:       %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-xml-curl

%description xml-curl
Provides XML Curl interface for the FreeSWITCH Open Source telephone platform.
Pull dynamic XML configs for FreeSWITCH over HTTP.

%package xml-rpc
Summary:        Provides XML-RPC interface for the FreeSWITCH Open Source telephone platform.
Group:          System/Libraries
Requires:        %{name}-libs = %{version}-%{release}
Provides:      %{name}-mod-xml-rpc

%description xml-rpc
Provides XML-RPC interface for the FreeSWITCH Open Source telephone platform.
%endif
######################################################################################################################
#			FreeSWITCH ESL language modules
######################################################################################################################

%package	-n perl-ESL
Summary:	The Perl ESL module allows for native interaction with FreeSWITCH over the event socket interface.
Group:		System Environment/Libraries
Requires:	perl
BuildRequires:	perl-devel
BuildRequires:	perl-ExtUtils-Embed

%description	-n perl-ESL
The Perl ESL module allows for native interaction with FreeSWITCH over the event socket interface.
######################################################################################################################
#				FreeSWITCH basic config module
######################################################################################################################
%if %{build_modules}

%package config-vanilla
Summary:        Basic vanilla config set for the FreeSWITCH Open Source telephone platform.
Group:          System/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	freeswitch-application-avmd
Requires:	freeswitch-application-blacklist
Requires:	freeswitch-application-callcenter
Requires:	freeswitch-application-cidlookup
Requires:	freeswitch-application-conference
Requires:	freeswitch-application-curl
Requires:	freeswitch-application-db
Requires:	freeswitch-application-directory
Requires:	freeswitch-application-distributor
Requires:	freeswitch-application-easyroute
Requires:	freeswitch-application-enum
Requires:	freeswitch-application-esf
Requires:	freeswitch-application-expr
Requires:	freeswitch-application-fifo
Requires:	freeswitch-application-fsk
Requires:	freeswitch-application-fsv
Requires:	freeswitch-application-hash
Requires:	freeswitch-application-httapi
Requires:	freeswitch-application-http-cache
Requires:	freeswitch-application-lcr
Requires:	freeswitch-application-limit
Requires:	freeswitch-application-memcache
Requires:	freeswitch-application-nibblebill
Requires:	freeswitch-application-redis
#Requires:	freeswitch-application-signalwire
Requires:	freeswitch-application-sms
Requires:	freeswitch-application-snapshot
Requires:	freeswitch-application-spy
Requires:	freeswitch-application-valet_parking
Requires:	freeswitch-application-video_filter
Requires:	freeswitch-application-voicemail
Requires:	freeswitch-application-voicemail-ivr
Requires:	freeswitch-codec-passthru-amr
Requires:	freeswitch-codec-bv
Requires:	freeswitch-codec-passthru-g723_1
Requires:	freeswitch-codec-passthru-g729
Requires:	freeswitch-codec-ilbc
Requires:	freeswitch-codec-siren
Requires:	freeswitch-database-pgsql
Requires:	freeswitch-format-local-stream
Requires:	freeswitch-format-native-file
Requires:	freeswitch-format-tone-stream
Requires:	freeswitch-lang-en

%description config-vanilla
Basic vanilla config set for the FreeSWITCH Open Source telephone platform.
%endif
######################################################################################################################
#
#				Unpack and prepare Source archives, copy stuff around etc ..
#
######################################################################################################################

%prep
%setup -b0 -q
%autopatch -p1
#Hotfix for redefined %_sysconfdir
#sed -ie 's:confdir="${sysconfdir}/freeswitch":confdir="$sysconfdir":' ./configure.ac

######################################################################################################################
#
#						Start the Build process
#
######################################################################################################################
%build
%ifos linux
%if 0%{?suse_version} > 1000 && 0%{?suse_version} < 1030
export CFLAGS="$CFLAGS -fstack-protector"
%endif
%if 0%{?fedora_version} >= 8
export QA_RPATHS=$[ 0x0001|0x0002 ]
%endif
%endif

######################################################################################################################
#
#				Here the modules that will be build get defined
#
######################################################################################################################
######################################################################################################################
#
#						Application Modules
#
######################################################################################################################
APPLICATION_MODULES_AC="applications/mod_avmd applications/mod_blacklist \
			applications/mod_callcenter  applications/mod_cidlookup \
			applications/mod_commands applications/mod_conference applications/mod_curl"
APPLICATION_MODULES_DE="applications/mod_db applications/mod_directory applications/mod_distributor \
			applications/mod_dptools applications/mod_easyroute applications/mod_enum applications/mod_esf \
			applications/mod_expr "

%if %{build_mod_esl}
APPLICATION_MODULES_DE+="applications/mod_esl"
%endif

APPLICATION_MODULES_FR="applications/mod_fifo applications/mod_fsk applications/mod_fsv applications/mod_hash \
			applications/mod_httapi applications/mod_http_cache applications/mod_lcr applications/mod_limit \
			applications/mod_memcache applications/mod_nibblebill \
			applications/mod_redis "
%if %{build_mongo}
APPLICATION_MODULES_FR="$APPLICATION_MODULES_FR mod_mongo"
%endif
APPLICATION_MODULES_SZ="applications/mod_sms applications/mod_snapshot \
			applications/mod_spandsp applications/mod_spy \
			applications/mod_valet_parking applications/mod_translate applications/mod_voicemail \
			applications/mod_voicemail_ivr applications/mod_video_filter"

APPLICATIONS_MODULES="$APPLICATION_MODULES_AC $APPLICATION_MODULES_DE $APPLICATION_MODULES_FR $APPLICATION_MODULES_SZ"

######################################################################################################################
#
#				Automatic Speech Recognition and Text To Speech Modules
#
######################################################################################################################
ASR_TTS_MODULES="asr_tts/mod_flite asr_tts/mod_tts_commandline"
%if %{build_pocketsphinx}
ASR_TTS_MODULES="$ASR_TTS_MODULES asr_tts/mod_pocketsphinx"
%endif
######################################################################################################################
#
#						Codecs
#
######################################################################################################################
CODECS_MODULES="codecs/mod_amr codecs/mod_amrwb codecs/mod_bv codecs/mod_codec2 codecs/mod_g723_1 \
		codecs/mod_g729 codecs/mod_ilbc codecs/mod_opus codecs/mod_silk \
		codecs/mod_siren"
#

######################################################################################################################
#
#					Database Modules
#
######################################################################################################################
DATABASES_MODULES="databases/mod_mariadb databases/mod_pgsql"

######################################################################################################################
#
#					Dialplan Modules
#
######################################################################################################################
DIALPLANS_MODULES="dialplans/mod_dialplan_directory dialplans/mod_dialplan_xml"
#DISABLED DIALPLANS dialplans/mod_dialplan_asterisk 
######################################################################################################################
#
#					Directory Modules
#
######################################################################################################################
DIRECTORIES_MODULES=""

######################################################################################################################
#
#						Endpoints
#
######################################################################################################################
ENDPOINTS_MODULES=" \
			endpoints/mod_loopback endpoints/mod_rtmp \
			endpoints/mod_skinny endpoints/mod_rtc endpoints/mod_sofia"
%if %{build_signalwire}
ENDPOINT_MODULES="$ENDPOINT_MODULES mod_verto"
%endif
## DISABLED MODULES DUE TO BUILD ISSUES endpoints/mod_h323
 
######################################################################################################################
#
#						Event Handlers
#
######################################################################################################################
EVENT_HANDLERS_MODULES="event_handlers/mod_cdr_csv event_handlers/mod_cdr_pg_csv event_handlers/mod_cdr_sqlite \
			event_handlers/mod_cdr_mongodb event_handlers/mod_format_cdr event_handlers/mod_erlang_event event_handlers/mod_event_multicast \
			event_handlers/mod_event_socket event_handlers/mod_json_cdr \
			event_handlers/mod_snmp"

######################################################################################################################
#
#					File and Audio Format Handlers
#
######################################################################################################################
FORMATS_MODULES="formats/mod_local_stream formats/mod_native_file formats/mod_opusfile \
                 formats/mod_shell_stream formats/mod_shout formats/mod_sndfile formats/mod_tone_stream"

######################################################################################################################
#
#						Embedded Languages
#
######################################################################################################################
LANGUAGES_MODULES="languages/mod_lua"
%if %{build_mod_perl}
LANGUAGES_MODULES+=" languages/mod_perl"
%endif
%if %{build_mod_v8}
LANGUAGES_MODULES+=" languages/mod_v8"
%endif

######################################################################################################################
#
#						Logging Modules
#
######################################################################################################################
LOGGERS_MODULES="loggers/mod_console loggers/mod_graylog2 loggers/mod_logfile loggers/mod_syslog"

######################################################################################################################
#
#						Phrase engine language modules
#
######################################################################################################################
SAY_MODULES="say/mod_say_de say/mod_say_en say/mod_say_es say/mod_say_pt say/mod_say_fr say/mod_say_he say/mod_say_ru say/mod_say_sv"

######################################################################################################################
#
#							Timers
#
######################################################################################################################
TIMERS_MODULES="timers/mod_posix_timer "
%if %{build_timerfd}
TIMERS_MODULES+="timers/mod_timerfd"
%endif

######################################################################################################################
#
#						XML Modules
#
######################################################################################################################
XML_INT_MODULES="xml_int/mod_xml_cdr xml_int/mod_xml_curl xml_int/mod_xml_rpc"

######################################################################################################################
#
#				Create one environment variable out of all the module defs
#
######################################################################################################################
MYMODULES="$APPLICATIONS_MODULES $CODECS_MODULES $DATABASES_MODULES $DIALPLANS_MODULES $DIRECTORIES_MODULES \
$ENDPOINTS_MODULES $ASR_TTS_MODULES $EVENT_HANDLERS_MODULES $FORMATS_MODULES $LANGUAGES_MODULES $LOGGERS_MODULES \
$SAY_MODULES $TIMERS_MODULES $XML_INT_MODULES"

######################################################################################################################
#
#					Create Modules build list and set variables
#
######################################################################################################################

export MODULES=$MYMODULES
test ! -f  modules.conf || rm -f modules.conf
touch modules.conf
cd src/mod
for mod in */*; do echo $mod >> ../../modules.conf; done
cd ../..
sed -i '/autotools/d' modules.conf
sed -i '/mod_v8/d' modules.conf
sed -i '/mod_perl/d' modules.conf
sed -i '/mod_signalwire/d' modules.conf
sed -i '/mod_verto/d' modules.conf
sed -i '/mod_alsa/d' modules.conf
sed -i '/mod_com_g729/d' modules.conf
sed -i '/mod_av$/d' modules.conf
sed -i '/mod_managed$/d' modules.conf
sed -i '/mod_pocketsphinx$/d' modules.conf
sed -i '/mod_smpp$/d' modules.conf
sed -i '/mod_webm$/d' modules.conf
#Deprecated header
sed -i '/mod_amqp$/d' modules.conf
#Can't find library
sed -i '/mod_h323$/d' modules.conf
#Discarded qualifiers
sed -i '/mod_imagick$/d' modules.conf
#javac not found
sed -i '/mod_java$/d' modules.conf
#deprecated-declarations
sed -i '/mod_mongo$/d' modules.conf
##error OPAL is too old to use, must be >= 3.12.8
sed -i '/mod_opal$/d' modules.conf
#fatal error: osp/osp.h: No such file or directory
sed -i '/mod_osp$/d' modules.conf
#mod_python3.c:35:10: fatal error: Python.h: No such file or directory
sed -i '/mod_python3$/d' modules.conf


#applications/mod_av
#applications/mod_cv
#applications/mod_hiredis
#applications/mod_mongo
#applications/mod_osp
#asr_tts/mod_pocketsphinx
#codecs/mod_com_g729
#codecs/mod_openh264
#directories/mod_ldap
#endpoints/mod_alsa
#endpoints/mod_h323
#endpoints/mod_opal
#event_handlers/mod_amqp
#event_handlers/mod_smpp
#formats/mod_imagick
#formats/mod_vlc
#formats/mod_webm
#languages/mod_java
#languages/mod_managed
#languages/mod_python3
#xml_int/mod_xml_ldap

#for i in $MODULES; do echo $i >> modules.conf; done
export VERBOSE=yes
export DESTDIR=%{buildroot}/
export PKG_CONFIG_PATH=/usr/bin/pkg-config:$PKG_CONFIG_PATH
export ACLOCAL_FLAGS="-I /usr/share/aclocal"

%if 0%{?rhel} == 7
# to build mod_mariadb we need gcc >= 4.9 (more details GH #1046)
export CFLAGS="$CFLAGS -Wno-error=expansion-to-defined"
. /opt/rh/devtoolset-9/enable
%endif
%if 0%{?rhel} == 8
# we want use fresh gcc on RHEL 8 based dists
. /opt/rh/gcc-toolset-9/enable
%endif

######################################################################################################################
#
#				Bootstrap, Configure and Build the whole enchilada
#
######################################################################################################################

if test -f bootstrap.sh
then 
   ./bootstrap.sh
else
   ./rebootstrap.sh
fi

autoreconf --force --install

%if 0%{?fedora} >= 43
export CFLAGS="$CFLAGS -DCURL_DISABLE_TYPECHECK"
%endif

%configure -C \
--prefix=%{PREFIX} \
--exec-prefix=%{EXECPREFIX} \
--bindir=%{BINDIR} \
--sbindir=%{SBINDIR} \
--libexecdir=%{LIBEXECDIR} \
--sharedstatedir=%{SHARESTATEDIR} \
--localstatedir=%{_localstatedir} \
--libdir=%{LIBDIR} \
--includedir=%{INCLUDEDIR} \
--datadir=%{DATADIR} \
--infodir=%{INFODIR} \
--mandir=%{MANDIR} \
--with-logfiledir=%{LOGFILEDIR} \
--with-modinstdir=%{MODINSTDIR} \
--with-rundir=%{RUNDIR} \
--with-dbdir=%{DBDIR} \
--with-htdocsdir=%{HTDOCSDIR} \
--with-soundsdir=%{SOUNDSDIR} \
--enable-core-odbc-support \
--enable-core-libedit-support \
--with-grammardir=%{GRAMMARDIR} \
--with-scriptdir=%{SCRIPTDIR} \
--with-recordingsdir=%{RECORDINGSDIR} \
--with-pkgconfigdir=%{PKGCONFIGDIR} \
--with-odbc \
--with-erlang \
--with-openssl \
--disable-rpath \
%if %{without core_vpx}
--disable-libvpx \
%endif
%if 0%{?rhel} == 9
%endif
%{?configure_options}

unset MODULES
%{__make}

cd libs/esl
%{__make} perlmod


######################################################################################################################
#
#				Install it and create some required dirs and links
#
######################################################################################################################
%install
%if 0%{?rhel} == 7
# to build mod_mariadb we need gcc >= 4.9
. /opt/rh/devtoolset-9/enable
%endif
%if 0%{?rhel} == 8
# we want use fresh gcc on RHEL 8 based dists
. /opt/rh/gcc-toolset-9/enable
%endif


%{__make} DESTDIR=%{buildroot} install

# Create a log dir
%{__mkdir} -p %{buildroot}/%{prefix}/log
%{__mkdir} -p %{buildroot}/%{LOGFILEDIR}
%{__mkdir} -p %{buildroot}/%{RUNDIR}
%{__mkdir} -p %{buildroot}%{_localstatedir}/cache/freeswitch

#install the esl stuff
cd libs/esl
%{__make} DESTDIR=%{buildroot} perlmod-install

cd ../..

%ifos linux
# Install init files
# On SuSE:
%if 0%{?suse_version} > 100
%{__install} -D -m 744 build/freeswitch.init.suse %{buildroot}/etc/rc.d/init.d/freeswitch
%else
%if "%{?_unitdir}" == ""
# On RedHat like
%{__install} -D -m 0755 build/freeswitch.init.redhat %{buildroot}/etc/rc.d/init.d/freeswitch
%else
# systemd
%{__install} -Dpm 0644 build/freeswitch.service %{buildroot}%{_unitdir}/freeswitch.service
%{__install} -Dpm 0644 build/freeswitch-tmpfiles.conf %{buildroot}%{_tmpfilesdir}/freeswitch.conf
%endif
%endif
# On SuSE make /usr/sbin/rcfreeswitch a link to /etc/rc.d/init.d/freeswitch
%if 0%{?suse_version} > 100
%{__mkdir} -p %{buildroot}/usr/sbin
%{__ln_s} -f /etc/rc.d/init.d/freeswitch %{buildroot}/usr/sbin/rcfreeswitch
%endif
# Add the sysconfiguration file
%{__install} -D -m 744 build/freeswitch.sysconfig %{buildroot}/etc/sysconfig/freeswitch
# Add monit file
%{__install} -D -m 644 build/freeswitch.monitrc %{buildroot}/etc/monit.d/freeswitch.monitrc
%endif
######################################################################################################################
#
#                               Remove files that are not wanted if they exist
#
######################################################################################################################

%{__rm} -f %{buildroot}/%{LIBDIR}/*.la
%{__rm} -f %{buildroot}/%{MODINSTDIR}/*.la
chrpath --delete $RPM_BUILD_ROOT%{_bindir}/freeswitch

######################################################################################################################
#
#			Add a freeswitch user with group daemon that will own the whole enchilada
#
######################################################################################################################
%pre
%ifos linux
if ! /usr/bin/id freeswitch &>/dev/null; then
       /usr/sbin/useradd -r -g daemon -s /bin/false -c "The FreeSWITCH Open Source Voice Platform" -d %{LOCALSTATEDIR} freeswitch || \
                %logmsg "Unexpected error adding user \"freeswitch\". Aborting installation."
fi
%endif

%post
%{?run_ldconfig:%run_ldconfig}
chown freeswitch:daemon /var/log/freeswitch /var/run/freeswitch

%if "%{?_unitdir}" == ""
chkconfig --add freeswitch
%else
%tmpfiles_create freeswitch
/usr/bin/systemctl -q enable freeswitch.service
%endif

%preun
%{?systemd_preun freeswitch.service}

%postun
%{?systemd_postun freeswitch.service}
######################################################################################################################
#
#				On uninstallation get rid of the freeswitch user
#
######################################################################################################################
%{?run_ldconfig:%run_ldconfig}
if [ $1 -eq 0 ]; then
    userdel freeswitch || %logmsg "User \"freeswitch\" could not be deleted."
fi

%clean
%{__rm} -rf %{buildroot}

%files
######################################################################################################################
#
#			What to install where ... first set default permissions
#
######################################################################################################################
%defattr(-,root,root)

######################################################################################################################
#
#							Directories
#
######################################################################################################################
#
#################################### Basic Directory Structure #######################################################
#
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/%{name}
%dir %attr(0750, freeswitch, daemon) %{LOCALSTATEDIR}
%dir %attr(0750, freeswitch, daemon) %{LOCALSTATEDIR}/images
%dir %attr(0750, freeswitch, daemon) %{DBDIR}
%dir %attr(0755, -, -) %{GRAMMARDIR}
%dir %attr(0755, -, -) %{HTDOCSDIR}
%dir %attr(0750, freeswitch, daemon) %{LOGFILEDIR}
%dir %attr(0750, freeswitch, daemon) %{RUNDIR}
%dir %attr(0755, -, -) %{SCRIPTDIR}
#
#################################### Config Directory Structure #######################################################
#
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/dialplan
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/dialplan/default
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/dialplan/public
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/dialplan/skinny-patterns
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/directory
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/directory/default
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/sip_profiles
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/sip_profiles/external
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/sip_profiles/external-ipv6
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/skinny_profiles
#
#################################### Grammar Directory Structure #####################################################
#
%if 0
%dir %attr(0755, -, -) %{GRAMMARDIR}/model
%dir %attr(0755, -, -) %{GRAMMARDIR}/model/communicator
%endif
######################################################################################################################
#
#						Other Files
#
######################################################################################################################
%config(noreplace) %attr(0644,-,-) %{HTDOCSDIR}/*
%ifos linux
%if "%{?_unitdir}" == ""
/etc/rc.d/init.d/freeswitch
%else
%{_unitdir}/freeswitch.service
%{_tmpfilesdir}/freeswitch.conf
%endif
%config(noreplace) /etc/sysconfig/freeswitch
%if 0%{?suse_version} > 100
/usr/sbin/rcfreeswitch
%endif
%endif
%ifos linux
%dir %attr(0750,-,-) /etc/monit.d
%config(noreplace) %attr(0644,-,-) /etc/monit.d/freeswitch.monitrc
%endif
%{LOCALSTATEDIR}/images/*

######################################################################################################################
#
#						Binaries
#
######################################################################################################################
%attr(0755,-,-) %{_prefix}/bin/freeswitch

%files libs
%{LIBDIR}/libfreeswitch*.so*

%files utils
%attr(0755,-,-) %{_prefix}/bin/fs_encode
%attr(0755,-,-) %{_prefix}/bin/fs_ivrd
%attr(0755,-,-) %{_prefix}/bin/fs_tts
%attr(0755,-,-) %{_prefix}/bin/fsxs
%attr(0755,-,-) %{_prefix}/bin/gentls_cert
%attr(0755,-,-) %{_prefix}/bin/switch_eavesdrop
%attr(0755,-,-) %{_prefix}/bin/tone2wav

%files cli
%attr(0755,-,-) %{_prefix}/bin/fs_cli

%files base-modules
######################################################################################################################
#
#			Modules in Alphabetical Order, please keep them that way..
#
######################################################################################################################
%{MODINSTDIR}/mod_cdr_csv.so*
%{MODINSTDIR}/mod_console.so*
%{MODINSTDIR}/mod_commands.so*
%{MODINSTDIR}/mod_dialplan_directory.so* 
%{MODINSTDIR}/mod_dialplan_xml.so* 
%{MODINSTDIR}/mod_dptools.so*
%{MODINSTDIR}/mod_event_socket.so*
%{MODINSTDIR}/mod_logfile.so*
%{MODINSTDIR}/mod_loopback.so*
%{MODINSTDIR}/mod_native_file.so*
%{MODINSTDIR}/mod_sndfile.so*
%{MODINSTDIR}/mod_sofia.so*
%{MODINSTDIR}/mod_spandsp.so*
%{MODINSTDIR}/mod_syslog.so*
%{MODINSTDIR}/mod_tone_stream.so*
######################################################################################################################
#
#						Package for the developer
#
######################################################################################################################
%files devel
%{LIBDIR}/*.so*
%{PKGCONFIGDIR}/*
%{INCLUDEDIR}/*.h
%{INCLUDEDIR}/test/*.h

%if %{build_modules}
######################################################################################################################
#						Vanilla Config Files
######################################################################################################################
%files config-vanilla
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/*.tpl
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/*.ttml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/extensions.conf
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/mime.types
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/acl.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/amr.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/amrwb.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/alsa.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/amqp.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/av.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/avmd.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/blacklist.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/callcenter.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/cdr_csv.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/cdr_mongodb.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/cdr_pg_csv.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/cdr_sqlite.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/cidlookup.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/conference.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/conference_layouts.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/console.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/curl.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/db.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/dialplan_directory.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/directory.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/distributor.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/easyroute.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/enum.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/erlang_event.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/event_multicast.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/event_socket.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/fax.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/fifo.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/format_cdr.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/graylog2.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/hash.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/hiredis.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/httapi.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/http_cache.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/ivr.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/java.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/lcr.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/local_stream.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/logfile.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/memcache.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/modules.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/mongo.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/msrp.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/nibblebill.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/opal.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/osp.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/pocketsphinx.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/post_load_modules.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/pre_load_modules.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/presence_map.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/redis.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/rtmp.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/shout.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/signalwire.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/skinny.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/smpp.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/sndfile.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/sofia.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/spandsp.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/switch.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/syslog.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/timezones.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/translate.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/tts_commandline.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/verto.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/voicemail.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/voicemail_ivr.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/vpx.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/xml_cdr.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/xml_curl.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/xml_rpc.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/xml_scgi.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/zeroconf.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/perl.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/python.conf.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/v8.conf.xml
######################################################################################################################
#						Chatplans
######################################################################################################################
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/chatplan/default.xml
######################################################################################################################
#						Dialplans
######################################################################################################################
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/dialplan/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/dialplan/default/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/dialplan/public/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/dialplan/skinny-patterns/*.xml
######################################################################################################################
#						Fonts
######################################################################################################################
%config(noreplace) %attr(0640, freeswitch, daemon) %{_datadir}/freeswitch/fonts/*.ttf
%config(noreplace) %attr(0640, freeswitch, daemon) %{_datadir}/freeswitch/fonts/OFL.txt
%config(noreplace) %attr(0640, freeswitch, daemon) %{_datadir}/freeswitch/fonts/README.fonts
######################################################################################################################
#						User Directories
######################################################################################################################
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/directory/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/directory/default/*
######################################################################################################################
#							IVR Menus
######################################################################################################################
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/ivr_menus/*.xml
######################################################################################################################
#							Sip Profiles
######################################################################################################################
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/sip_profiles/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/sip_profiles/external/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/sip_profiles/external-ipv6/*.xml
######################################################################################################################
#				Other Protocol Profiles (skinny)
######################################################################################################################
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/skinny_profiles/*.xml
######################################################################################################################
#						Grammar Files
######################################################################################################################
%if 0
%config(noreplace) %attr(0644, -, -) %{GRAMMARDIR}/default.dic
%config(noreplace) %attr(0644, -, -) %{GRAMMARDIR}/model/communicator/*
%endif

### END OF config-vanilla
%endif
%if %{build_modules}

######################################################################################################################
#
#						Application Packages
#
######################################################################################################################
%files application-avmd
%{MODINSTDIR}/mod_avmd.so*

%files application-blacklist
%{MODINSTDIR}/mod_blacklist.so*

%files application-callcenter
%{MODINSTDIR}/mod_callcenter.so*

%files application-cidlookup
%{MODINSTDIR}/mod_cidlookup.so*

%files application-conference
%{MODINSTDIR}/mod_conference.so*

%files application-curl
%{MODINSTDIR}/mod_curl.so*

%files application-db
%{MODINSTDIR}/mod_db.so*

%files application-directory
%{MODINSTDIR}/mod_directory.so*

%files application-distributor
%{MODINSTDIR}/mod_distributor.so*

%files application-easyroute
%{MODINSTDIR}/mod_easyroute.so*

%files application-enum
%{MODINSTDIR}/mod_enum.so*

%files application-esf
%{MODINSTDIR}/mod_esf.so*

%if %{build_mod_esl}
%files application-esl
%{MODINSTDIR}/mod_esl.so*
%endif

%files application-expr
%{MODINSTDIR}/mod_expr.so*

%files application-fifo
%{MODINSTDIR}/mod_fifo.so*

%files application-fsk
%{MODINSTDIR}/mod_fsk.so*

%files application-fsv
%{MODINSTDIR}/mod_fsv.so*

%files application-hash
%{MODINSTDIR}/mod_hash.so*

%files application-httapi
%{MODINSTDIR}/mod_httapi.so*

%files application-http-cache
%dir %attr(0750, freeswitch, daemon) %{_localstatedir}/cache/freeswitch
%{MODINSTDIR}/mod_http_cache.so*

%files application-lcr
%{MODINSTDIR}/mod_lcr.so*

%files application-limit
%{MODINSTDIR}/mod_limit.so*

%files application-memcache
%{MODINSTDIR}/mod_memcache.so*

%if %{build_mongo}
%files application-mongo
%{MODINSTDIR}/mod_mongo.so*
%endif

%files application-nibblebill
%{MODINSTDIR}/mod_nibblebill.so*

%files application-redis
%{MODINSTDIR}/mod_redis.so*

#%files application-signalwire
#%{MODINSTDIR}/mod_signalwire.so*

%files application-sms
%{MODINSTDIR}/mod_sms.so*

%files application-snapshot
%{MODINSTDIR}/mod_snapshot.so*

%files application-spy
%{MODINSTDIR}/mod_spy.so*

%files application-translate
%{MODINSTDIR}/mod_translate.so*

%files application-valet_parking
%{MODINSTDIR}/mod_valet_parking.so*

%files application-video_filter
%{MODINSTDIR}/mod_video_filter.so*

%files application-voicemail
%{MODINSTDIR}/mod_voicemail.so*

%files application-voicemail-ivr
%{MODINSTDIR}/mod_voicemail_ivr.so*

######################################################################################################################
#
#						ASR TTS Packages
#
######################################################################################################################
%files asrtts-flite
%{MODINSTDIR}/mod_flite.so*

%if %{build_pocketsphinx}
%files asrtts-pocketsphinx
%{MODINSTDIR}/mod_pocketsphinx.so*
%endif

%files asrtts-tts-commandline
%{MODINSTDIR}/mod_tts_commandline.so*

######################################################################################################################
#
#						CODEC Packages
#
######################################################################################################################

%files codec-passthru-amr
%{MODINSTDIR}/mod_amr.so*

%files codec-passthru-amrwb
%{MODINSTDIR}/mod_amrwb.so*

%files codec-bv
%{MODINSTDIR}/mod_bv.so*

%files codec-codec2
%{MODINSTDIR}/mod_codec2.so*


%files codec-passthru-g723_1
%{MODINSTDIR}/mod_g723_1.so*

%files codec-passthru-g729
%{MODINSTDIR}/mod_g729.so*

%files codec-ilbc
%{MODINSTDIR}/mod_ilbc.so*

%files codec-opus
%{MODINSTDIR}/mod_opus.so*
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/opus.conf.xml

%files codec-silk
%{MODINSTDIR}/mod_silk.so*

%files codec-siren
%{MODINSTDIR}/mod_siren.so*

######################################################################################################################
#
#						FreeSWITCH Database Modules
#
######################################################################################################################

%files database-mariadb
%{MODINSTDIR}/mod_mariadb.so*

%files database-pgsql
%{MODINSTDIR}/mod_pgsql.so*

######################################################################################################################
#
#						FreeSWITCH Directory Modules
#
######################################################################################################################

%files directory-ldap
%{MODINSTDIR}/mod_ldap.so*

######################################################################################################################
#
#						FreeSWITCH endpoint Modules
#
######################################################################################################################

%dnl %files endpoint-h323
%dnl %{MODINSTDIR}/mod_h323.so*

%files endpoint-rtmp
%{MODINSTDIR}/mod_rtmp.so*

%files endpoint-skinny
%{MODINSTDIR}/mod_skinny.so*

%if %{build_signalwire}
%files endpoint-verto
%{MODINSTDIR}/mod_verto.so*
%endif

%files endpoint-rtc
%{MODINSTDIR}/mod_rtc.so*


######################################################################################################################
#
#					Event Modules
#
######################################################################################################################

%files event-cdr-mongodb
%{MODINSTDIR}/mod_cdr_mongodb.so*

%files event-cdr-pg-csv
%{MODINSTDIR}/mod_cdr_pg_csv.so*

%files event-cdr-sqlite
%{MODINSTDIR}/mod_cdr_sqlite.so*

%files event-erlang-event
%{MODINSTDIR}/mod_erlang_event.so*

%files event-format-cdr
%{MODINSTDIR}/mod_format_cdr.so*

%files event-multicast
%{MODINSTDIR}/mod_event_multicast.so*

%files event-json-cdr
%{MODINSTDIR}/mod_json_cdr.so*

%files event-snmp
%{MODINSTDIR}/mod_snmp.so*

######################################################################################################################
#
#					Event Modules
#
######################################################################################################################

%files format-local-stream
%{MODINSTDIR}/mod_local_stream.so*

%files format-native-file
%{MODINSTDIR}/mod_native_file.so*

%files format-opusfile
%{MODINSTDIR}/mod_opusfile.so*

%files format-shell-stream
%{MODINSTDIR}/mod_shell_stream.so*

%files format-mod-shout
%{MODINSTDIR}/mod_shout.so*

%files format-tone-stream
%{MODINSTDIR}/mod_tone_stream.so*

######################################################################################################################
#
#					Embedded Language Modules
#
######################################################################################################################
%files lua
%{MODINSTDIR}/mod_lua*.so*
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/autoload_configs/lua.conf.xml

%if %{build_mod_perl}

%files perl
%{MODINSTDIR}/mod_perl*.so*
%{prefix}/perl/*
%endif

%if %{build_mod_v8}
%files v8
%{MODINSTDIR}/mod_v8*.so*
%{LIBDIR}/libv8.so
%{LIBDIR}/libicui18n.so
%{LIBDIR}/libicuuc.so
%endif
%endif
######################################################################################################################
#
#						Language Modules
#
######################################################################################################################
%files lang-en
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/en
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/en/demo
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/en/vm
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/en/dir
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/en/ivr
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/en/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/en/demo/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/en/vm/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/en/dir/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/en/ivr/*.xml
%{MODINSTDIR}/mod_say_en.so*

%files lang-de
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/de
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/de/demo
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/de/vm
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/de/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/de/demo/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/de/vm/*.xml
%{MODINSTDIR}/mod_say_de.so*

%files lang-fr
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/fr
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/fr/demo
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/fr/vm
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/fr/dir
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/fr/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/fr/demo/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/fr/vm/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/fr/dir/*.xml
%{MODINSTDIR}/mod_say_fr.so*

%files lang-ru
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/ru
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/ru/demo
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/ru/vm
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/ru/dir
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/ru/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/ru/demo/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/ru/vm/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/ru/dir/*.xml
%{MODINSTDIR}/mod_say_ru.so*

%files lang-he
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/he/
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/he/demo
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/he/vm
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/he/dir
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/he/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/he/demo/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/he/vm/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/he/dir/*.xml
%{MODINSTDIR}/mod_say_he.so*

%files lang-es
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/es
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/es/demo
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/es/vm
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/es/dir
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/es/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/es/demo/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/es/vm/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/es/dir/*.xml
%{MODINSTDIR}/mod_say_es.so*

%files lang-pt
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/pt
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/pt/demo
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/pt/vm
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/pt/dir
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/pt/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/pt/demo/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/pt/vm/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/pt/dir/*.xml
%{MODINSTDIR}/mod_say_pt.so*

%files lang-sv
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/sv
%dir %attr(0750, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/sv/vm
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/sv/*.xml
%config(noreplace) %attr(0640, freeswitch, daemon) %{_sysconfdir}/freeswitch/lang/sv/vm/*.xml
%{MODINSTDIR}/mod_say_sv.so*

######################################################################################################################
#
#						Logger Modules
#
######################################################################################################################
%if %{build_modules}

%files logger-graylog2
%{MODINSTDIR}/mod_graylog2.so*
%endif
######################################################################################################################
#
#					Timer Modules
#
######################################################################################################################
%if %{build_modules}

%files timer-posix
%{MODINSTDIR}/mod_posix_timer.so*

%if %{build_timerfd}
%files timer-timerfd
%{MODINSTDIR}/mod_timerfd.so*
%endif
%endif
######################################################################################################################
#
#					XMLINT  Modules
#
######################################################################################################################
%if %{build_modules}

%files xml-cdr
%{MODINSTDIR}/mod_xml_cdr.so*

%files xml-curl
%{MODINSTDIR}/mod_xml_curl.so*

%files xml-rpc
%{MODINSTDIR}/mod_xml_rpc.so*

%endif

%files extra-modules
%{MODINSTDIR}/mod_b64.so
%{MODINSTDIR}/mod_basic.so
%{MODINSTDIR}/mod_bert.so
%{MODINSTDIR}/mod_cluechoo.so
%{MODINSTDIR}/mod_cv.so
%{MODINSTDIR}/mod_dialplan_asterisk.so
%{MODINSTDIR}/mod_event_test.so
%{MODINSTDIR}/mod_fail2ban.so
%{MODINSTDIR}/mod_hiredis.so
%{MODINSTDIR}/mod_odbc_cdr.so
%{MODINSTDIR}/mod_openh264.so
%{MODINSTDIR}/mod_png.so
%{MODINSTDIR}/mod_prefix.so
%{MODINSTDIR}/mod_random.so
%{MODINSTDIR}/mod_reference.so
%{MODINSTDIR}/mod_say_es_ar.so
%{MODINSTDIR}/mod_say_fa.so
%{MODINSTDIR}/mod_say_hr.so
%{MODINSTDIR}/mod_say_hu.so
%{MODINSTDIR}/mod_say_it.so
%{MODINSTDIR}/mod_say_ja.so
%{MODINSTDIR}/mod_say_nl.so
%{MODINSTDIR}/mod_say_pl.so
%{MODINSTDIR}/mod_say_th.so
%{MODINSTDIR}/mod_say_zh.so
%{MODINSTDIR}/mod_skel.so
%{MODINSTDIR}/mod_skel_codec.so
%{MODINSTDIR}/mod_test.so
%{MODINSTDIR}/mod_timerfd.so
%{MODINSTDIR}/mod_vlc.so
%{MODINSTDIR}/mod_vmd.so
%{MODINSTDIR}/mod_xml_ldap.so
%{MODINSTDIR}/mod_xml_scgi.so
%{MODINSTDIR}/mod_yuv.so


######################################################################################################################
#			FreeSWITCH ESL language modules
######################################################################################################################

%files	-n perl-ESL
%defattr(644,root,root,755)
#{perl_archlib}/ESL.pm
%{perl_archlib}/ESL.*
#{perl_archlib}/ESL.la
%dir %{perl_archlib}/ESL
%{perl_archlib}/ESL/Dispatch.pm
%{perl_archlib}/ESL/IVR.pm
######################################################################################################################
#
#						Changelog
#
######################################################################################################################
%changelog
* Fri Jan 31 2020 - Andrey Volk
- Add sndfile.conf.xml
* Tue Apr 23 2019 - Andrey Volk
- Fix build for Stack 20.x
* Tue Dec 11 2018 - Andrey Volk
- add mod_signalwire
* Sun Mar 13 2016 - Matthew Vale
- add perl and python ESL language module packages
* Thu Jul 09 2015 - Artur Zaprzała
- add systemd service file for CentOS 7
* Thu Jun 25 2015 - s.safarov@gmail.com
- Dependencies of mod_shout were declared
* Mon Jun 22 2015 - krice@freeswitch.org
- disable mod_shout until we can figure out the correct system deps for RPM based platforms
* Wed Jun 17 2015 - krice@freeswitch.org
- Update libvpx2 dep requirement
* Thu Jun 04 2015 - s.safarov@gmail.com
- Build dependences declared
- mod_rad_auth, mod_radius_cdr, mod_format_cdr modules declared
* Tue Nov 04 2014 - crienzo@grasshopper.com
- add mod_graylog2 and mod_mongo
* Thu Sep 11 2014 - krice@freeswitch.org
- add and fix mod_verto and mod_rtc
* Mon Jun 02 2014 - krice@freeswitch.org
- remove mod_spidermoney as its been deprecated
* Fri Feb 21 2014 - crienzo@grasshopper.com
- change file owner to root
* Wed Feb 19 2014 - crienzo@grasshopper.com
- remove mod_speex
* Sun Feb 02 2014 - jakob@mress.se
- add support for building Swedish say language module
* Mon Jan 13 2014 - peter@olssononline.se
- Add mod_v8
* Mon Dec 09 2013 - crienzo@grasshopper.com
- Add mod_ssml, mod_rayo
- Fix build on master
* Fri Jun 28 2013 - krice@freeswitch.org
- Add module for VP8
* Wed Jun 19 2013 - krice@freeswitch.org
- tweak files included for vanilla configs
* Wed Sep 19 2012 - krice@freeswitch.org
- Add support for Spanish and Portuguese say language modules
* Thu Jan 26 2012 - krice@freeswitch.org
- complete rework of spec file
* Tue Jun 14 2011 - michal.bielicki@seventhsignal.de
- added mod_http_cache
* Tue Jun 14 2011 - michal.bielicki@seventhsignal.de
- added mod_rtmp
* Fri Apr 01 2011 - michal.bielicki@seventhsignal.de
- added hebrew language stuff
* Wed Mar 30 2011 - michal.bielicki@seventhsignal.de
- removed mod_file_string since it has been merged into dptools
* Wed Feb 16 2011 - michal.bielicki@seventhsignal.de
- added mod_skinny
- added sangoma libraries
- added sangoma codec module for D100 and D150 and D500
- added skypopen module
- fixes for ss7 freetdm modules
- added mod_opus
- added selector for sangoma modules
- added python esl module to rpm
- some minor cleanups
- cut sangoma modules into separate rpms as addons for freetdm
* Tue Jan 18 2011 - michal.bielicki@seventhsignal.de
- Fedora adjustments
* Fri Oct 15 2010 - michal.bielicki@seventhsignal.de
- added mod_curl
* Sat Oct 09 2010 - michal.bielicki@seventhsignal.de
- added mod_silk
- added mod_codec2
- moved from openzap to freetdm to make way for inclusion of libsng_isdn and wanpipe
- added mod_freetdm
- added mod_cidlookup
- added more runtime dependencies
* Thu Sep 30 2010 - michal.bielicki@seventhsignal.de
- added mod_nibblebill to standard modules
* Sun Sep 26 2010 - michal.bielicki@seventhsignal.de
- added portaudio_stream module
- some more formatting work
* Mon Jul 19 2010 - michal.bielicki@seventhsignal.de
- new hash module config file added to freeswitch.spec
* Mon Jul 19 2010 - michal.bielicki@seventhsignal.de
- Adjusted sphinxbase
- Fixed Version Revisions for head versions
- Renamed packages to head to comply with git
* Tue Jun 22 2010 - michal.bielicki@seventhsignal.de
- Added comments and made the spec file sections more transparent
- Added proper header to the Spec file
- Added Contributors
- Added Anthony's copyright for the whole package into the header
* Tue Jun 22 2010 - michal.bielicki@seventhsignal.de
- Reorganized the modules alphabetically
- synced SFEopensolaris and centos spec
- started to fix Run Dependencies
- added mod_say_ru which seemd to have gone missing
- added comment blocks to show the spec file structure for easier management and editing
* Mon Jun 21 2010 - michal.bielicki@seventhsignal.de
- added mod_limit shim for backwards compatibility
- added mod_hash correctly
* Sun Jun 20 2010 - michal.bielicki@seventhsignal.de
- replaced mod_limit with mod_db
- added mod_spy
- added mod_valet_parking
- added mod_memcache
- added mod_distributor
- added mod_avmd
* Thu Apr 29 2010 - michal.bielicki@seventhsignal.de
- added osp conf file
* Fri Apr 23 2010 - michal.bielicki@seventhsignal.de
- bumped spec file vrersion up to 1.0.7-trunk for trunk
- added skinny dialplan stuff to specfile
* Sun Mar 28 2010 - michal.bielicki@seventhsignal.de
- added sangoma codec config file
* Wed Dec 02 2009 - michal.bielicki@seventhsignal.de
- Soundfiles are moving into a separate spec
* Wed Nov 25 2009 - brian@freeswitch.org
- added mod_bv.so
* Wed Nov 25 2009 - michal.bielicki@seventhsignal.de
- Removed mod_yaml
- added directory files to russian language
* Sat Nov 21 2009 - michal.bielicki@seventhsignal.de
- added patch by Igor Neves <neves.igor@gmail.com>: Added some checkup in %post and %postun to prevent upgrades from removing freeswitch user
* Wed Nov 18 2009 - michal.bielicki@seventhsignal.de
- added new config files for directory and distributor
- removed sangoma boost from openzap for builds that do not inherit wanpipe while building.
* Fri Jul 24 2009 - mike@jerris.com
- removed mod_http
- removed ozmod_wanpipe
* Tue Jun 23 2009 - raulfragoso@gmail.com
- Adjusted for the latest SVN trunk (13912)
- Included new config and mod files to catch up with latest SVN
- Included new sound files for base256 and zrtp
- mod_unimrcp must be built after mod_sofia
* Tue Feb 17 2009 - michal.bielicki@halokwadrat.de
- added mod_python
- added mod_fax
- added mod_amrwb.so
- added mod_celt.so
- added mod_easyroute.so
- added mod_http.so
- added mod_lcr.so
- added mod_loopback.so
- added mod_siren.so
- added mod/mod_stress.so
- added mod_yaml.so
- added mod_shout.so
- added rpms or all sounds
- openzap is now its own rpm
- added french
- added german
- added missing dependencies
- added soundfiles with separate rpms
- added definition of all sourcefiles and added them to the SRPM
- fixes to monit file
- changes to redhat init file
* Thu May 22 2008 - michal.bielicki@voiceworks.pl
- disabled beta class language stuff
- bumped revision up to rc6
- added mod_lua
- added mod_perl
- Only bootstrap if no Makfile.in exists
* Mon Feb 04 2008 - michal.bielicki@voiceworks.pl
- More fixes to specfile
- First go at SFE files
* Sun Feb 03 2008 - michal.bielicki@voiceworks.pl
- abstraction of prefix
- more wrong stuff deleted
- abstraction of mkdir, mv, rm, install etc into macros
* Fri Jan 18 2008 - michal.bielicki@voiceworks.pl
- fixes, fixes and more fixes in preparation for rc1
* Wed Dec 5 2007 - michal.bielicki@voiceworks.pl
- put in detail configfiles in to split of spidermonkey configs
- created link from /opt/freesxwitch/conf to /etc%{prefix}
* Thu Nov 29 2007 - michal.bielicki@voiceworks.pl
- Added ifdefs for susealities
- Added specifics for centos/redhat
- Added specifics for fedora
- Preparing to use it for adding it to SFE packaging for solaris
- Added odbc stuff back in
- made curl default
- Separate package for mod_spidermonkey
- got rid of modules.conf and stuffed everything in MODULES env var
- got rid of handmade Cflags peter added ;)
- fixed bin and libpaths
- fixed locationof nspr and js libs
- fixed odbc requirements
- added all buildable modules
- added redhat style init file
- split off language dependent stuff into separate language files
- disable non complete language modules
* Tue Apr 24 2007 - peter+rpmspam@suntel.com.tr
- Added a debug package
- Split the passthrough codecs into separate packages
* Fri Mar 16 2007 - peter+rpmspam@suntel.com.tr
- Added devel package
* Thu Mar 15 2007 - peter+rpmspam@suntel.com.tr
- Initial RPM release

